#ifndef LANGUAGE_H
#define LANGUAGE_H

// NOTE: IF YOU CHANGE THIS FILE / MERGE THIS FILE WITH CHANGES
//
//   ==> ALWAYS TRY TO COMPILE MARLIN WITH/WITHOUT "ULTIPANEL" / "ULTRALCD" / "SDSUPPORT" #define IN "Configuration.h" 
//   ==> ALSO TRY ALL AVAILABLE "LANGUAGE_CHOICE" OPTIONS

// Languages
// 1  English
// 2  Polish
// 3  French
// 4  German
// 5  Spanish
// 6  Russian
// 7  Italian
// 8  Portuguese
// 9  Finnish
// 10 Aragonese
// 11 Dutch

#ifndef LANGUAGE_CHOICE
	#define LANGUAGE_CHOICE 1  // Pick your language from the list above
#endif

#define PROTOCOL_VERSION "1.0"

#if defined(WITBOX)
	#define MACHINE_NAME "bq Witbox"
	#define FIRMWARE_URL "http://www.bqreaders.com/descargas-witbox.html"
	#define FIRMWARE_VER "v1.4.2"
	#define BUILD_VER ""
#elif defined(CUSTOM_MENDEL_NAME)
	#define MACHINE_NAME CUSTOM_MENDEL_NAME
#else
	// Default firmware set to Mendel
	#define MACHINE_NAME "Mendel"
	#define FIRMWARE_URL "https://github.com/ErikZalm/Marlin/"
#endif

#ifndef MACHINE_UUID
   #define MACHINE_UUID "00000000-0000-0000-0000-000000000000"
#endif


#define STRINGIFY_(n) #n
#define STRINGIFY(n) STRINGIFY_(n)


// Common LCD messages
/* nothing here as of yet */

// Common serial messages
#define MSG_MARLIN "Marlin"

// Serial Console Messages

#define MSG_Enqueing "enqueing \""
#define MSG_POWERUP "PowerUp"
#define MSG_EXTERNAL_RESET " External Reset"
#define MSG_BROWNOUT_RESET " Brown out Reset"
#define MSG_WATCHDOG_RESET " Watchdog Reset"
#define MSG_SOFTWARE_RESET " Software Reset"
#define MSG_AUTHOR " | Author: "
#define MSG_CONFIGURATION_VER " Last Updated: "
#define MSG_FREE_MEMORY " Free Memory: "
#define MSG_PLANNER_BUFFER_BYTES "  PlannerBufferBytes: "
#define MSG_OK "ok"
#define MSG_FILE_SAVED "Done saving file."
#define MSG_ERR_LINE_NO "Line Number is not Last Line Number+1, Last Line: "
#define MSG_ERR_CHECKSUM_MISMATCH "checksum mismatch, Last Line: "
#define MSG_ERR_NO_CHECKSUM "No Checksum with line number, Last Line: "
#define MSG_ERR_NO_LINENUMBER_WITH_CHECKSUM "No Line Number with checksum, Last Line: "
#define MSG_FILE_PRINTED "Done printing file"
#define MSG_BEGIN_FILE_LIST "Begin file list"
#define MSG_END_FILE_LIST "End file list"
#define MSG_M104_INVALID_EXTRUDER "M104 Invalid extruder "
#define MSG_M105_INVALID_EXTRUDER "M105 Invalid extruder "
#define MSG_M200_INVALID_EXTRUDER "M200 Invalid extruder "
#define MSG_M218_INVALID_EXTRUDER "M218 Invalid extruder "
#define MSG_ERR_NO_THERMISTORS "No thermistors - no temperature"
#define MSG_M109_INVALID_EXTRUDER "M109 Invalid extruder "
#define MSG_HEATING "Heating..."
#define MSG_HEATING_COMPLETE "Heating done."
#define MSG_BED_HEATING "Bed Heating."
#define MSG_BED_DONE "Bed done."
#define MSG_M115_REPORT "FIRMWARE_NAME:Marlin V1; Sprinter/grbl mashup for gen6 FIRMWARE_URL:" FIRMWARE_URL " PROTOCOL_VERSION:" PROTOCOL_VERSION " MACHINE_TYPE:" MACHINE_NAME " EXTRUDER_COUNT:" STRINGIFY(EXTRUDERS) " UUID:" MACHINE_UUID "\n"
#define MSG_COUNT_X " Count X: "
#define MSG_ERR_KILLED "Printer halted. kill() called!"
#define MSG_ERR_STOPPED "Printer stopped due to errors. Fix the error and use M999 to restart. (Temperature is reset. Set it after restarting)"
#define MSG_RESEND "Resend: "
#define MSG_UNKNOWN_COMMAND "Unknown command: \""
#define MSG_ACTIVE_EXTRUDER "Active Extruder: "
#define MSG_INVALID_EXTRUDER "Invalid extruder"
#define MSG_X_MIN "x_min: "
#define MSG_X_MAX "x_max: "
#define MSG_Y_MIN "y_min: "
#define MSG_Y_MAX "y_max: "
#define MSG_Z_MIN "z_min: "
#define MSG_Z_MAX "z_max: "
#define MSG_M119_REPORT "Reporting endstop status"
#define MSG_ENDSTOP_HIT "TRIGGERED"
#define MSG_ENDSTOP_OPEN "open"
#define MSG_HOTEND_OFFSET "Hotend offsets:"

#define MSG_SD_CANT_OPEN_SUBDIR "Cannot open subdir"
#define MSG_SD_INIT_FAIL "SD init fail"
#define MSG_SD_VOL_INIT_FAIL "volume.init failed"
#define MSG_SD_OPENROOT_FAIL "openRoot failed"
#define MSG_SD_CARD_OK "SD card ok"
#define MSG_SD_WORKDIR_FAIL "workDir open failed"
#define MSG_SD_OPEN_FILE_FAIL "open failed, File: "
#define MSG_SD_FILE_OPENED "File opened: "
#define MSG_SD_SIZE " Size: "
#define MSG_SD_FILE_SELECTED "File selected"
#define MSG_SD_WRITE_TO_FILE "Writing to file: "
#define MSG_SD_PRINTING_BYTE "SD printing byte "
#define MSG_SD_NOT_PRINTING "Not SD printing"
#define MSG_SD_ERR_WRITE_TO_FILE "error writing to file"
#define MSG_SD_CANT_ENTER_SUBDIR "Cannot enter subdir: "

#define MSG_STEPPER_TOO_HIGH "Steprate too high: "
#define MSG_ENDSTOPS_HIT "endstops hit: "
#define MSG_ERR_COLD_EXTRUDE_STOP " cold extrusion prevented"
#define MSG_ERR_LONG_EXTRUDE_STOP " too long extrusion prevented"
#define MSG_BABYSTEPPING_X "Babystepping X"
#define MSG_BABYSTEPPING_Y "Babystepping Y"
#define MSG_BABYSTEPPING_Z "Babystepping Z"
#define MSG_SERIAL_ERROR_MENU_STRUCTURE "Error in menu structure"

// LCD Menu Messages
#if LANGUAGE_CHOICE == 1
#define WELCOME_MSG MACHINE_NAME         " ready"
#define MSG_SD_INSERTED                  "Card inserted"
#define MSG_SD_REMOVED                   "Card removed"
#define MSG_MAIN                         "Main"
#define MSG_BACK                         "Back"
#define MSG_AUTOSTART                    "Autostart"
#define MSG_DISABLE_STEPPERS             "Disable steppers"
#define MSG_AUTO_HOME                    "Auto home"
#define MSG_SET_ORIGIN                   "Set origin"
#define MSG_PREHEAT_PLA                  "Preheat PLA"
#define MSG_PREHEAT_PLA_SETTINGS         "Preheat PLA conf"
#define MSG_PREHEAT_ABS                  "Preheat ABS"
#define MSG_PREHEAT_ABS_SETTINGS         "Preheat ABS conf"
#define MSG_COOLDOWN                     "Cooldown"
#define MSG_SWITCH_PS_ON                 "Switch power on"
#define MSG_SWITCH_PS_OFF                "Switch power off"
#define MSG_EXTRUDE                      "Extrude"
#define MSG_RETRACT                      "Retract"
#define MSG_MOVE_AXIS                    "Move axis"
#define MSG_MOVE_X                       "Move X"
#define MSG_MOVE_Y                       "Move Y"
#define MSG_MOVE_Z                       "Move Z"
#define MSG_MOVE_E                       "Extruder"
#define MSG_MOVE_01MM                    "Move 0.1mm"
#define MSG_MOVE_1MM                     "Move 1mm"
#define MSG_MOVE_10MM                    "Move 10mm"
#define MSG_SPEED                        "Speed"
#define MSG_NOZZLE                       "Temperature"
#define MSG_NOZZLE1                      "Nozzle2"
#define MSG_NOZZLE2                      "Nozzle3"
#define MSG_BED                          "Bed"
#define MSG_FAN_SPEED                    "Fan speed"
#define MSG_FLOW                         "Flow"
#define MSG_CONTROL                      "Control"
#define MSG_MIN                          " \002 Min"
#define MSG_MAX                          " \002 Max"
#define MSG_FACTOR                       " \002 Fact"
#define MSG_AUTOTEMP                     "Autotemp"
#define MSG_ON                           "On "
#define MSG_OFF                          "Off"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Accel"
#define MSG_VXY_JERK                     "Vxy-jerk"
#define MSG_VZ_JERK                      "Vz-jerk"
#define MSG_VE_JERK                      "Ve-jerk"
#define MSG_VMAX                         "Vmax "
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "Vmin"
#define MSG_VTRAV_MIN                    "VTrav min"
#define MSG_AMAX                         "Amax "
#define MSG_A_RETRACT                    "A-retract"
#define MSG_XSTEPS                       "Xsteps/mm"
#define MSG_YSTEPS                       "Ysteps/mm"
#define MSG_ZSTEPS                       "Zsteps/mm"
#define MSG_ESTEPS                       "Esteps/mm"
#define MSG_RECTRACT                     "Rectract"
#define MSG_TEMPERATURE                  "Temperature"
#define MSG_MOTION                       "Motion"
#define MSG_CONTRAST                     "LCD contrast"
#define MSG_STORE_EPROM                  "Store memory"
#define MSG_LOAD_EPROM                   "Load memory"
#define MSG_RESTORE_FAILSAFE             "Restore failsafe"
#define MSG_REFRESH                      "Refresh"
#define MSG_WATCH                        "Info screen"
#define MSG_PREPARE                      "Prepare"
#define MSG_TUNE                         "Tune"
#define MSG_PAUSE_PRINT                  "Pause print"
#define MSG_PAUSED                       "Press to resume"
#define MSG_PAUSING                      "Pausing..."
#define MSG_PRINTING                     "Printing..."
#define MSG_READY_UNLOAD                 "Press & unload fil."
#define MSG_UNLOAD_CLICK                 "Press to continue"
#define MSG_LOAD_CLICK                   "Load new filament"
#define MSG_RESUME_PRINT                 "Resume print"
#define MSG_STOP_PRINT                   "Stop print"
#define MSG_CARD_MENU                    "Print from SD"
#define MSG_NO_CARD                      "No SD card"
#define MSG_DWELL                        "Sleep..."
#define MSG_USERWAIT                     "Wait for user..."
#define MSG_RESUMING                     "Resuming print"
#define MSG_NO_MOVE                      "No move."
#define MSG_KILLED                       "KILLED. "
#define MSG_STOPPED                      "STOPPED. "
#define MSG_CONTROL_RETRACT              "Retract mm"
#define MSG_CONTROL_RETRACTF             "Retract F"
#define MSG_CONTROL_RETRACT_ZLIFT        "Hop mm"
#define MSG_CONTROL_RETRACT_RECOVER      "UnRet +mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "UnRet F"
#define MSG_AUTORETRACT                  "AutoRetr."
#define MSG_FILAMENTCHANGE               "Change filament"
#define MSG_INIT_SDCARD                  "Init. SD card"
#define MSG_CNG_SDCARD                   "Change SD card"
#define MSG_ZPROBE_OUT                   "Z probe out. bed"
#define MSG_POSITION_UNKNOWN             "Home X/Y before Z"
#define MSG_ZPROBE_ZOFFSET               "Z Offset"
#define MSG_BABYSTEP_X                   "Babystep X"
#define MSG_BABYSTEP_Y                   "Babystep Y"
#define MSG_BABYSTEP_Z                   "Babystep Z"
#define MSG_ENDSTOP_ABORT                "Endstop abort"
#define MSG_END_HOUR                     "hours"
#define MSG_END_MINUTE                   "minutes"
#define MSG_FILAMENT                     "Filament"
#define MSG_LEVEL_PLATE                  "Level plate"
#define MSG_START_SCRIPT                 "Start script"
#define MSG_PREHEAT                      "Preheat"
#define MSG_JOG                          "Jog"
#define MSG_LOAD                         "Load"
#define MSG_UNLOAD                       "Unload"
#define MSG_ABORT                        "Abort"
#define MSG_PRE_EXTRUD                   "Insert & Press"
#define MSG_EXTRUDING                    "Extruding..."
#define MSG_LENGTH                       "Length:"
#define MSG_RETRACTING                   "Retracting"
#define MSG_LP_COOL_1                    "Cooling..."
#define MSG_LP_COOL_2                    "Temp:"
#define MSG_LP_COOL_3                    " Press to abort"
#define MSG_LB_COOL_1                    "Cooling..."
#define MSG_LB_COOL_2                    "Temp:"
#define MSG_CF_HEAT_1                    "Heating..."
#define MSG_CF_HEAT_2                    "Temp:"
#define MSG_EXIT                         "Press to abort..."
#define MSG_WIZARD_LEVELBED_0_1          " Leveling plate... "
#define MSG_WIZARD_LEVELBED_0_2          " Press to start "
#define MSG_WIZARD_LEVELBED_1_1          " Adjust first point "
#define MSG_WIZARD_LEVELBED_1_2          " & Press the button "
#define MSG_WIZARD_LEVELBED_2_1          "Adjust second point "
#define MSG_WIZARD_LEVELBED_2_2          " & Press the button "
#define MSG_WIZARD_LEVELBED_3_1          " Adjust third point "
#define MSG_WIZARD_LEVELBED_3_2          " & Press the button "
#define MSG_WIZARD_LEVELBED_4_1          "Adjust fourth point "
#define MSG_WIZARD_LEVELBED_4_2          " & Press the button "
#define MSG_WIZARD_LEVELBED_5_1          " Is it ok? "
#define MSG_WIZARD_LEVELBED_6_1          " Plate leveled! "
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Press the button to "
#define MSG_WIZARD_CHANGEFILAMENT_0_1    " start the process "
#define MSG_WIZARD_CHANGEFILAMENT_0_2    "and extract filament"
#define MSG_WIZARD_CHANGEFILAMENT_1_0    " Pull the filament "
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "quickly when it has "
#define MSG_WIZARD_CHANGEFILAMENT_1_2    " stopped extruding "
#define MSG_WIZARD_CHANGEFILAMENT_2_0    " Insert the new "
#define MSG_WIZARD_CHANGEFILAMENT_2_1    " filament and press "
#define MSG_WIZARD_CHANGEFILAMENT_2_2    " the button "
#define MSG_WIZARD_CHANGEFILAMENT_3_0    " When the filament "
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "extrudes, press the "
#define MSG_WIZARD_CHANGEFILAMENT_3_2    " button to resume "
#define MSG_WIZARD_CHANGEFILAMENT_3_3    " printing "
#define MSG_SD_BAD_FILENAME              "Bad filename!"
#define MSG_HEATING_PROCESS              "Heating..."
#define MSG_HEATING_DONE                 "Heating done."
#define MSG_BED_HEATING_PROCESS          "Bed Heating."
#define MSG_BED_HEATING_DONE             "Bed done."
#define MSG_ENDSTOPS_TOUCH               "endstops hit: "
#endif



#if LANGUAGE_CHOICE == 3
#define WELCOME_MSG MACHINE_NAME         " prete"
#define MSG_SD_INSERTED                  "Carte inseree"
#define MSG_SD_REMOVED                   "Carte retiree"
#define MSG_MAIN                         "Menu principal"
#define MSG_BACK                         "Retour"
#define MSG_AUTOSTART                    "Demarrage auto"
#define MSG_DISABLE_STEPPERS             "Desactiv. moteurs"
#define MSG_AUTO_HOME                    "Retour origine"
#define MSG_SET_ORIGIN                   "Definir origine"
#define MSG_PREHEAT_PLA                  "Prechauffer le PLA"
#define MSG_PREHEAT_PLA_SETTINGS         "Conf prechauffe PLA"
#define MSG_PREHEAT_ABS                  "Prechauffer ABS"
#define MSG_PREHEAT_ABS_SETTINGS         "Conf prechauffe ABS"
#define MSG_COOLDOWN                     "Refroidir"
#define MSG_SWITCH_PS_ON                 "Allumer"
#define MSG_SWITCH_PS_OFF                "Eteindre"
#define MSG_EXTRUDE                      "Extruder"
#define MSG_RETRACT                      "Retracter"
#define MSG_MOVE_AXIS                    "Deplacer axe"
#define MSG_MOVE_X                       "Deplacer X"
#define MSG_MOVE_Y                       "Deplacer Y"
#define MSG_MOVE_Z                       "Deplacer Z"
#define MSG_MOVE_E                       "Extrudeuse"
#define MSG_MOVE_01MM                    "Deplacer 0,1mm"
#define MSG_MOVE_1MM                     "Deplacer 1mm"
#define MSG_MOVE_10MM                    "Deplacer 10mm"
#define MSG_SPEED                        "Vitesse"
#define MSG_NOZZLE                       "Temperature"
#define MSG_NOZZLE1                      "Embout2"
#define MSG_NOZZLE2                      "Embout3"
#define MSG_BED                          "Plateau"
#define MSG_FAN_SPEED                    "Vitesse ventilateur"
#define MSG_FLOW                         "Flux"
#define MSG_CONTROL                      "Controle"
#define MSG_MIN                          " \002 Min"
#define MSG_MAX                          " \002 Max"
#define MSG_FACTOR                       " \002 Fact"
#define MSG_AUTOTEMP                     "Autotemp"
#define MSG_ON                           "On "
#define MSG_OFF                          "Off"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Accel."
#define MSG_VXY_JERK                     "Vxy-jerk"
#define MSG_VZ_JERK                      "Vz-jerk"
#define MSG_VE_JERK                      "Ve-jerk"
#define MSG_VMAX                         "Vmax "
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "Vmin"
#define MSG_VTRAV_MIN                    "VTrav min"
#define MSG_AMAX                         "Amax "
#define MSG_A_RETRACT                    "A-retract"
#define MSG_XSTEPS                       "X pas/mm"
#define MSG_YSTEPS                       "Y pas/mm"
#define MSG_ZSTEPS                       "Z pas/mm"
#define MSG_ESTEPS                       "E pas/mm"
#define MSG_RECTRACT                     "Retracter"
#define MSG_TEMPERATURE                  "Temperature"
#define MSG_MOTION                       "Mouvement"
#define MSG_CONTRAST                     "Contraste ecran LCD"
#define MSG_STORE_EPROM                  "Stocker memoire"
#define MSG_LOAD_EPROM                   "Charger memoire"
#define MSG_RESTORE_FAILSAFE             "Restauration urgente"
#define MSG_REFRESH                      "Rafraichir"
#define MSG_WATCH                        "Ecran info"
#define MSG_PREPARE                      "Preparer"
#define MSG_TUNE                         "Syntonisation"
#define MSG_PAUSE_PRINT                  "Pause impression"
#define MSG_PAUSED                       "Appuy pour reprendre"
#define MSG_PAUSING                      "En pause..."
#define MSG_PRINTING                     "Impression en cours"
#define MSG_READY_UNLOAD                 "Appuy. & retirer fil"
#define MSG_UNLOAD_CLICK                 "Appuy pour continuer"
#define MSG_LOAD_CLICK                   "Charger nv filament"
#define MSG_RESUME_PRINT                 "Reprendre impression"
#define MSG_STOP_PRINT                   "Cesser impression"
#define MSG_CARD_MENU                    "Impr. depuis SD"
#define MSG_NO_CARD                      "Pas de carte SD"
#define MSG_DWELL                        "En veille"
#define MSG_USERWAIT                     "En attente"
#define MSG_RESUMING                     "Reprise impression"
#define MSG_NO_MOVE                      "Aucun mouvement"
#define MSG_KILLED                       "Arret d'urgence. "
#define MSG_STOPPED                      "ARRETE "
#define MSG_CONTROL_RETRACT              "Retracter mm"
#define MSG_CONTROL_RETRACTF             "Retracter F"
#define MSG_CONTROL_RETRACT_ZLIFT        "Hop mm"
#define MSG_CONTROL_RETRACT_RECOVER      "UnRet +mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "UnRet F"
#define MSG_AUTORETRACT                  "AutoRetr."
#define MSG_FILAMENTCHANGE               "Changer filament"
#define MSG_INIT_SDCARD                  "Init. carte SD"
#define MSG_CNG_SDCARD                   "Changer carte SD"
#define MSG_ZPROBE_OUT                   "verif. Z hors base"
#define MSG_POSITION_UNKNOWN             "Origine X/Y avant Z"
#define MSG_ZPROBE_ZOFFSET               "Z Offset"
#define MSG_BABYSTEP_X                   "Minipas X"
#define MSG_BABYSTEP_Y                   "Minipas Y"
#define MSG_BABYSTEP_Z                   "Minipas Z"
#define MSG_ENDSTOP_ABORT                "Butoir annuler"
#define MSG_END_HOUR                     "heures"
#define MSG_END_MINUTE                   "minutes"
#define MSG_FILAMENT                     "Filament"
#define MSG_LEVEL_PLATE                  "Niveler plateau"
#define MSG_START_SCRIPT                 "Demarrer script"
#define MSG_PREHEAT                      "Prechauffer"
#define MSG_JOG                          "Deplacer"
#define MSG_LOAD                         "Charger"
#define MSG_UNLOAD                       "Retirer"
#define MSG_ABORT                        "Annuler"
#define MSG_PRE_EXTRUD                   "Inserer & appuyer"
#define MSG_EXTRUDING                    "Extrusion en cours"
#define MSG_LENGTH                       "Longueur :"
#define MSG_RETRACTING                   "Retractation..."
#define MSG_LP_COOL_1                    "Refroidissement..."
#define MSG_LP_COOL_2                    "Temp."
#define MSG_LP_COOL_3                    "Appuyer pour annuler"
#define MSG_LB_COOL_1                    "Refroidissement..."
#define MSG_LB_COOL_2                    "Temp."
#define MSG_CF_HEAT_1                    "En chauffe..."
#define MSG_CF_HEAT_2                    "Temp."
#define MSG_EXIT                         "Appuyer pour annuler"
#define MSG_WIZARD_LEVELBED_0_1          "Nivellement plateau"
#define MSG_WIZARD_LEVELBED_0_2          "Appuyer pour debuter"
#define MSG_WIZARD_LEVELBED_1_1          " Nivelez 1er point "
#define MSG_WIZARD_LEVELBED_1_2          "& appuyer sur bouton"
#define MSG_WIZARD_LEVELBED_2_1          " Nivelez 2eme point "
#define MSG_WIZARD_LEVELBED_2_2          "& appuyer sur bouton"
#define MSG_WIZARD_LEVELBED_3_1          " Nivelez 3eme point "
#define MSG_WIZARD_LEVELBED_3_2          "& appuyer sur bouton"
#define MSG_WIZARD_LEVELBED_4_1          " Nivelez 4eme point "
#define MSG_WIZARD_LEVELBED_4_2          "& appuyer sur bouton"
#define MSG_WIZARD_LEVELBED_5_1          "Verifiez le centre"
#define MSG_WIZARD_LEVELBED_6_1          " Plateau nivele ! "
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Appuy. bouton pour"
#define MSG_WIZARD_CHANGEFILAMENT_0_1    "debuter le processus"
#define MSG_WIZARD_CHANGEFILAMENT_0_2    " & retirer filament"
#define MSG_WIZARD_CHANGEFILAMENT_1_0    "Retirer le filament"
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "rapidement quand"
#define MSG_WIZARD_CHANGEFILAMENT_1_2    "il aura ete expulse"
#define MSG_WIZARD_CHANGEFILAMENT_2_0    "Inserer le nouveau"
#define MSG_WIZARD_CHANGEFILAMENT_2_1    "filament et appuyer"
#define MSG_WIZARD_CHANGEFILAMENT_2_2    "sur le bouton"
#define MSG_WIZARD_CHANGEFILAMENT_3_0    "Quand le filament"
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "est rentre, appuyer"
#define MSG_WIZARD_CHANGEFILAMENT_3_2    "sur le bouton pour"
#define MSG_WIZARD_CHANGEFILAMENT_3_3    "reprendre impression"
#define MSG_SD_BAD_FILENAME              "Mauvais nom fichier!"
#define MSG_HEATING_PROCESS              "En chauffe..."
#define MSG_HEATING_DONE                 "Chauffe terminee."
#define MSG_BED_HEATING_PROCESS          "Plateau en chauffe."
#define MSG_BED_HEATING_DONE             "Plateau OK."
#define MSG_ENDSTOPS_TOUCH               "Butoir touche: "
#endif


#if LANGUAGE_CHOICE == 4
#define WELCOME_MSG MACHINE_NAME         " fertig"
#define MSG_SD_INSERTED                  "Karte eingesetzt"
#define MSG_SD_REMOVED                   "Karte entfernt"
#define MSG_MAIN                         "Hauptmenue"
#define MSG_BACK                         "Zurueck"
#define MSG_AUTOSTART                    "Autostart"
#define MSG_DISABLE_STEPPERS             "Motoren deakt."
#define MSG_AUTO_HOME                    "Zum Anfang gehen"
#define MSG_SET_ORIGIN                   "Anfang festlegen"
#define MSG_PREHEAT_PLA                  "PLA vorwaermen"
#define MSG_PREHEAT_PLA_SETTINGS         "PLA Temp. anpassen"
#define MSG_PREHEAT_ABS                  "ABS vorwaermen"
#define MSG_PREHEAT_ABS_SETTINGS         "ABS Temp. anpassen"
#define MSG_COOLDOWN                     "Abkuehlen"
#define MSG_SWITCH_PS_ON                 "Switch power on"
#define MSG_SWITCH_PS_OFF                "Switch power off"
#define MSG_EXTRUDE                      "Extrudieren"
#define MSG_RETRACT                      "Retract"
#define MSG_MOVE_AXIS                    "Achsen bewegen"
#define MSG_MOVE_X                       "X bewegen"
#define MSG_MOVE_Y                       "Y bewegen"
#define MSG_MOVE_Z                       "Z bewegen"
#define MSG_MOVE_E                       "Extruder"
#define MSG_MOVE_01MM                    "0.1mm bewegen"
#define MSG_MOVE_1MM                     "1mm bewegen"
#define MSG_MOVE_10MM                    "10mm bewegen"
#define MSG_SPEED                        "Geschwindigkeit"
#define MSG_NOZZLE                       "Temperatur"
#define MSG_NOZZLE1                      "Einspritzduese2"
#define MSG_NOZZLE2                      "Einspritzduese3"
#define MSG_BED                          "Bett"
#define MSG_FAN_SPEED                    "Lueftergeschw."
#define MSG_FLOW                         "Fluss"
#define MSG_CONTROL                      "Einstellungen"
#define MSG_MIN                          " \002 Min"
#define MSG_MAX                          " \002 Max"
#define MSG_FACTOR                       " \002 Faktor"
#define MSG_AUTOTEMP                     "Autotemp"
#define MSG_ON                           "Ein "
#define MSG_OFF                          "AUS"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Accel"
#define MSG_VXY_JERK                     "Vxy-jerk"
#define MSG_VZ_JERK                      "Vz-jerk"
#define MSG_VE_JERK                      "Ve-jerk"
#define MSG_VMAX                         "Vmax "
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "Vmin"
#define MSG_VTRAV_MIN                    "VTrav min"
#define MSG_AMAX                         "Amax "
#define MSG_A_RETRACT                    "A-retract"
#define MSG_XSTEPS                       "XSchritte/mm"
#define MSG_YSTEPS                       "YSchritte/mm"
#define MSG_ZSTEPS                       "ZSchritte/mm"
#define MSG_ESTEPS                       "ESchritte/mm"
#define MSG_RECTRACT                     "Retract"
#define MSG_TEMPERATURE                  "Temperatur"
#define MSG_MOTION                       "Bewegung"
#define MSG_CONTRAST                     "LCD Kontrast"
#define MSG_STORE_EPROM                  "Speicher ablegen"
#define MSG_LOAD_EPROM                   "Speicher laden"
#define MSG_RESTORE_FAILSAFE             "Standardkonf"
#define MSG_REFRESH                      "Aktualisieren"
#define MSG_WATCH                        "Start"
#define MSG_PREPARE                      "Vorbereiten"
#define MSG_TUNE                         "Justierung"
#define MSG_PAUSE_PRINT                  "Druck pausieren"
#define MSG_PAUSED                       "Druecke fuer weiter"
#define MSG_PAUSING                      "Pausiert..."
#define MSG_PRINTING                     "Druckt..."
#define MSG_READY_UNLOAD                 "Druecken & Fil. ausgeben"
#define MSG_UNLOAD_CLICK                 "Druecke fuer weiter"
#define MSG_LOAD_CLICK                   "Neues Filament laden"
#define MSG_RESUME_PRINT                 "Mit dem Druck fortfahren"
#define MSG_STOP_PRINT                   "Druck stoppen"
#define MSG_CARD_MENU                    "Von SD drucken"
#define MSG_NO_CARD                      "Keine SD Karte"
#define MSG_DWELL                        "Ruhen..."
#define MSG_USERWAIT                     "Warte auf Nutzer..."
#define MSG_RESUMING                     "Druck fortsetzen"
#define MSG_NO_MOVE                      "Keine Bewegung."
#define MSG_KILLED                       "STILLSTAND"
#define MSG_STOPPED                      "GESTOPPT. "
#define MSG_CONTROL_RETRACT              "Retract mm"
#define MSG_CONTROL_RETRACTF             "Retract F"
#define MSG_CONTROL_RETRACT_ZLIFT        "Hop mm"
#define MSG_CONTROL_RETRACT_RECOVER      "UnRet +mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "UnRet F"
#define MSG_AUTORETRACT                  "AutoRetr."
#define MSG_FILAMENTCHANGE               "Filament wechseln"
#define MSG_INIT_SDCARD                  "SD- Karte starten"
#define MSG_CNG_SDCARD                   "SD- Karte wechseln"
#define MSG_ZPROBE_OUT                   "Z probe out. bed"
#define MSG_POSITION_UNKNOWN             "Home X/Y before Z"
#define MSG_ZPROBE_ZOFFSET               "Z Offset"
#define MSG_BABYSTEP_X                   "Babystep X"
#define MSG_BABYSTEP_Y                   "Babystep Y"
#define MSG_BABYSTEP_Z                   "Babystep Z"
#define MSG_ENDSTOP_ABORT                "Endstop abort"
#define MSG_END_HOUR                     "Stunden"
#define MSG_END_MINUTE                   "Minuten"
#define MSG_FILAMENT                     "Filament"
#define MSG_LEVEL_PLATE                  "Platte justieren"
#define MSG_START_SCRIPT                 "Script starten"
#define MSG_PREHEAT                      "Vorwaermen"
#define MSG_JOG                          "Jog"
#define MSG_LOAD                         "Laden"
#define MSG_UNLOAD                       "Entfernen"
#define MSG_ABORT                        "Abbrechen"
#define MSG_PRE_EXTRUD                   "Einfue. & drueck."
#define MSG_EXTRUDING                    "Extrudiert..."
#define MSG_LENGTH                       "Laenge:"
#define MSG_RETRACTING                   "Retracting"
#define MSG_LP_COOL_1                    "Kuehlt..."
#define MSG_LP_COOL_2                    "Temp:"
#define MSG_LP_COOL_3                    "Druecken zum Abbruch"
#define MSG_LB_COOL_1                    "Kuehlt..."
#define MSG_LB_COOL_2                    "Temp:"
#define MSG_CF_HEAT_1                    "Heizt..."
#define MSG_CF_HEAT_2                    "Temp:"
#define MSG_EXIT                         "Druecken zum Abbruch"
#define MSG_WIZARD_LEVELBED_0_1          " Platte kalibrieren "
#define MSG_WIZARD_LEVELBED_0_2          " Druecken fuer Start"
#define MSG_WIZARD_LEVELBED_1_1          " 1. Punkt justieren"
#define MSG_WIZARD_LEVELBED_1_2          " & Knopf druecken"
#define MSG_WIZARD_LEVELBED_2_1          "2. Punkt justieren "
#define MSG_WIZARD_LEVELBED_2_2          " & Knopf druecken "
#define MSG_WIZARD_LEVELBED_3_1          " 3. Punkt justieren "
#define MSG_WIZARD_LEVELBED_3_2          " & Knopf druecken "
#define MSG_WIZARD_LEVELBED_4_1          "4. Punkt justieren "
#define MSG_WIZARD_LEVELBED_4_2          " & Knopf druecken "
#define MSG_WIZARD_LEVELBED_5_1          " Ist es so gut? "
#define MSG_WIZARD_LEVELBED_6_1          " Platte kalibriert! "
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Knopf druecken um "
#define MSG_WIZARD_CHANGEFILAMENT_0_1    " Prozess zu starten "
#define MSG_WIZARD_CHANGEFILAMENT_0_2    "und Fil. auszugeben"
#define MSG_WIZARD_CHANGEFILAMENT_1_0    " Ziehe schnell am"
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "Filament wenn"
#define MSG_WIZARD_CHANGEFILAMENT_1_2    " Extrudieren stoppt "
#define MSG_WIZARD_CHANGEFILAMENT_2_0    " Setze das neue "
#define MSG_WIZARD_CHANGEFILAMENT_2_1    " Fil. ein u. druecke"
#define MSG_WIZARD_CHANGEFILAMENT_2_2    " den Knopf "
#define MSG_WIZARD_CHANGEFILAMENT_3_0    " Wenn das Filament "
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "extrud. druecke den "
#define MSG_WIZARD_CHANGEFILAMENT_3_2    " Knopf um weiter "
#define MSG_WIZARD_CHANGEFILAMENT_3_3    " zu drucken "
#define MSG_SD_BAD_FILENAME              "Unguelt. Dateiname!"
#define MSG_HEATING_PROCESS              "Heizen..."
#define MSG_HEATING_DONE                 "Heizen abgeschl."
#define MSG_BED_HEATING_PROCESS          "Bett heizen."
#define MSG_BED_HEATING_DONE             "Druckbett fertig."
#define MSG_ENDSTOPS_TOUCH               "Endstops erreicht: "
#endif


#if LANGUAGE_CHOICE == 5
#define WELCOME_MSG MACHINE_NAME         " lista"
#define MSG_SD_INSERTED                  "Tarjeta insertada"
#define MSG_SD_REMOVED                   "Tarjeta retirada"
#define MSG_MAIN                         "Menu principal"
#define MSG_BACK                         "Atras"
#define MSG_AUTOSTART                    " Autoarranque"
#define MSG_DISABLE_STEPPERS             "Apagar motores"
#define MSG_AUTO_HOME                    "Llevar al origen"
#define MSG_SET_ORIGIN                   "Establecer origen"
#define MSG_PREHEAT_PLA                  "Precalentar PLA"
#define MSG_PREHEAT_PLA_SETTINGS         "Ajustar temp. PLA"
#define MSG_PREHEAT_ABS                  "Precalentar ABS"
#define MSG_PREHEAT_ABS_SETTINGS         "Ajustar temp. ABS"
#define MSG_COOLDOWN                     "Enfriar"
#define MSG_SWITCH_PS_ON                 "Encender"
#define MSG_SWITCH_PS_OFF                "Apagar"
#define MSG_EXTRUDE                      "Extruir"
#define MSG_RETRACT                      "Retraer"
#define MSG_MOVE_AXIS                    "Mover ejes"
#define MSG_MOVE_X                       "Mover X"
#define MSG_MOVE_Y                       "Mover Y"
#define MSG_MOVE_Z                       "Mover Z"
#define MSG_MOVE_E                       "Extrusor"
#define MSG_MOVE_01MM                    "Mover 0.1 mm"
#define MSG_MOVE_1MM                     "Mover 1 mm"
#define MSG_MOVE_10MM                    "Mover 10 mm"
#define MSG_SPEED                        "Velocidad"
#define MSG_NOZZLE                       "Temperatura"
#define MSG_NOZZLE1                      "Inyector2"
#define MSG_NOZZLE2                      "Inyector3"
#define MSG_BED                          "Base"
#define MSG_FAN_SPEED                    "Ventilador"
#define MSG_FLOW                         "Flujo"
#define MSG_CONTROL                      "Control"
#define MSG_MIN                          "\002 Min"
#define MSG_MAX                          "\002 Max"
#define MSG_FACTOR                       "\002 Fact"
#define MSG_AUTOTEMP                     "Autotemp"
#define MSG_ON                           "On"
#define MSG_OFF                          "Off"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Acel"
#define MSG_VXY_JERK                     "Vxy-jerk"
#define MSG_VZ_JERK                      "Vz-jerk"
#define MSG_VE_JERK                      "Ve-jerk"
#define MSG_VMAX                         "Vmax"
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "Vmin"
#define MSG_VTRAV_MIN                    "VTrav min"
#define MSG_AMAX                         "Amax"
#define MSG_A_RETRACT                    "A-retrac."
#define MSG_XSTEPS                       "X pasos/mm"
#define MSG_YSTEPS                       "Y pasos/mm"
#define MSG_ZSTEPS                       "Z pasos/mm"
#define MSG_ESTEPS                       "E pasos/mm"
#define MSG_RECTRACT                     "Retraer"
#define MSG_TEMPERATURE                  "Temperatura"
#define MSG_MOTION                       "Movimiento"
#define MSG_CONTRAST                     "Contraste de LCD"
#define MSG_STORE_EPROM                  "Guardar memoria"
#define MSG_LOAD_EPROM                   "Cargar memoria"
#define MSG_RESTORE_FAILSAFE             "Rest. de emergen."
#define MSG_REFRESH                      "Volver a cargar"
#define MSG_WATCH                        "Inicio"
#define MSG_PREPARE                      "Preparar"
#define MSG_TUNE                         "Ajustar"
#define MSG_PAUSE_PRINT                  "Pausar impresion"
#define MSG_PAUSED                       "Pulsa para seguir"
#define MSG_PAUSING                      "Pausando..."
#define MSG_PRINTING                     "Imprimiendo..."
#define MSG_READY_UNLOAD                 "Pulsa y extrae fila."
#define MSG_UNLOAD_CLICK                 "Pulsa para continuar"
#define MSG_LOAD_CLICK                   "Carga filamento"
#define MSG_RESUME_PRINT                 "Reanudar impr."
#define MSG_STOP_PRINT                   "Detener impresion"
#define MSG_CARD_MENU                    "Tarjeta SD"
#define MSG_NO_CARD                      "No hay tarjeta SD"
#define MSG_DWELL                        "Reposo..."
#define MSG_USERWAIT                     "Esperando ordenes"
#define MSG_RESUMING                     "Reanudando impr."
#define MSG_NO_MOVE                      "Sin movimiento"
#define MSG_KILLED                       "PARADA DE EMERG."
#define MSG_STOPPED                      "PARADA"
#define MSG_CONTROL_RETRACT              "Retraer mm"
#define MSG_CONTROL_RETRACTF             "Retraer V"
#define MSG_CONTROL_RETRACT_ZLIFT        "Levantar mm"
#define MSG_CONTROL_RETRACT_RECOVER      "DesRet +mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "DesRet V"
#define MSG_AUTORETRACT                  "AutoRetr."
#define MSG_FILAMENTCHANGE               "Cambiar filamento"
#define MSG_INIT_SDCARD                  "Iniciando tarjeta"
#define MSG_CNG_SDCARD                   "Cambiar tarjeta"
#define MSG_ZPROBE_OUT                   "Z probe out. bed"
#define MSG_POSITION_UNKNOWN             "Home X/Y before Z"
#define MSG_ZPROBE_ZOFFSET               "Z Offset"
#define MSG_BABYSTEP_X                   "Minipaso X"
#define MSG_BABYSTEP_Y                   "Minipaso Y"
#define MSG_BABYSTEP_Z                   "Minipaso Z"
#define MSG_ENDSTOP_ABORT                "Anular endstop"
#define MSG_END_HOUR                     "horas"
#define MSG_END_MINUTE                   "minutos"
#define MSG_FILAMENT                     "Filamento"
#define MSG_LEVEL_PLATE                  "Nivelar base"
#define MSG_START_SCRIPT                 "Iniciar script"
#define MSG_PREHEAT                      "Calentar"
#define MSG_JOG                          "Mover"
#define MSG_LOAD                         "Cargar"
#define MSG_UNLOAD                       "Descargar"
#define MSG_ABORT                        "Atras"
#define MSG_PRE_EXTRUD                   "Insertar & pulsar"
#define MSG_EXTRUDING                    "Extruyendo..."
#define MSG_LENGTH                       "Longitud:"
#define MSG_RETRACTING                   "Retrayendo"
#define MSG_LP_COOL_1                    "Enfriando..."
#define MSG_LP_COOL_2                    "Temp:"
#define MSG_LP_COOL_3                    " Pulsa para salir"
#define MSG_LB_COOL_1                    "Cooling..."
#define MSG_LB_COOL_2                    "Temp:"
#define MSG_CF_HEAT_1                    "Heating..."
#define MSG_CF_HEAT_2                    "Temp:"
#define MSG_EXIT                         "Press to abort..."
#define MSG_WIZARD_LEVELBED_0_1          "Nivelando la base..."
#define MSG_WIZARD_LEVELBED_0_2          " Pulsa para empezar "
#define MSG_WIZARD_LEVELBED_1_1          " Nivela el punto 1 "
#define MSG_WIZARD_LEVELBED_1_2          " Pulsa la rueda "
#define MSG_WIZARD_LEVELBED_2_1          " Nivela el punto 2 "
#define MSG_WIZARD_LEVELBED_2_2          " Pulsa la rueda "
#define MSG_WIZARD_LEVELBED_3_1          " Nivela el punto 3 "
#define MSG_WIZARD_LEVELBED_3_2          " Pulsa la rueda "
#define MSG_WIZARD_LEVELBED_4_1          " Nivela el punto 4 "
#define MSG_WIZARD_LEVELBED_4_2          " Pulsa la rueda "
#define MSG_WIZARD_LEVELBED_5_1          "Comprueba el centro "
#define MSG_WIZARD_LEVELBED_6_1          " Base nivelada "
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Pulsa el boton para "
#define MSG_WIZARD_CHANGEFILAMENT_0_1    " iniciar el proceso "
#define MSG_WIZARD_CHANGEFILAMENT_0_2    "y extraer filamento "
#define MSG_WIZARD_CHANGEFILAMENT_1_0    " Tira rapidamente "
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "del filamento cuando"
#define MSG_WIZARD_CHANGEFILAMENT_1_2    " termine de extruir "
#define MSG_WIZARD_CHANGEFILAMENT_2_0    " Inserta el nuevo "
#define MSG_WIZARD_CHANGEFILAMENT_2_1    " filamento y pulsa "
#define MSG_WIZARD_CHANGEFILAMENT_2_2    " el boton "
#define MSG_WIZARD_CHANGEFILAMENT_3_0    " Cuando extruya el "
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "filamento, pulsa el "
#define MSG_WIZARD_CHANGEFILAMENT_3_2    "boton para reanudar "
#define MSG_WIZARD_CHANGEFILAMENT_3_3    " la impresion "
#define MSG_SD_BAD_FILENAME              "Nombre ilegal"
#define MSG_HEATING_PROCESS              "Calentando..."
#define MSG_HEATING_DONE                 "Fin calentamiento"
#define MSG_BED_HEATING_PROCESS          "Calentando cama"
#define MSG_BED_HEATING_DONE             "Fin cal. cama"
#define MSG_ENDSTOPS_TOUCH               "fin de carrera: "
#endif


#if LANGUAGE_CHOICE == 7
#define WELCOME_MSG MACHINE_NAME         " pronta"
#define MSG_SD_INSERTED                  "SD Card inserita"
#define MSG_SD_REMOVED                   "SD Card rimossa"
#define MSG_MAIN                         "Menu principale"
#define MSG_BACK                         "Indietro"
#define MSG_AUTOSTART                    "Avvio automatico"
#define MSG_DISABLE_STEPPERS             "Disabilita motori"
#define MSG_AUTO_HOME                    "Auto home"
#define MSG_SET_ORIGIN                   "Imposta origine"
#define MSG_PREHEAT_PLA                  "Preriscalda PLA"
#define MSG_PREHEAT_PLA_SETTINGS         "Config. prerisc. PLA"
#define MSG_PREHEAT_ABS                  "Preriscalda ABS"
#define MSG_PREHEAT_ABS_SETTINGS         "Config. prerisc. ABS"
#define MSG_COOLDOWN                     "Raffredda"
#define MSG_SWITCH_PS_ON                 "Accendi"
#define MSG_SWITCH_PS_OFF                "Spegni"
#define MSG_EXTRUDE                      "Estrudi"
#define MSG_RETRACT                      "Ritrai"
#define MSG_MOVE_AXIS                    "Muovi assi"
#define MSG_MOVE_X                       "Muovi X"
#define MSG_MOVE_Y                       "Muovi Y"
#define MSG_MOVE_Z                       "Muovi Z"
#define MSG_MOVE_E                       "Estrudi"
#define MSG_MOVE_01MM                    "Sposta 0,1 mm"
#define MSG_MOVE_1MM                     "Sposta 1 mm"
#define MSG_MOVE_10MM                    "Sposta 10 mm"
#define MSG_SPEED                        "Velocita "
#define MSG_NOZZLE                       "Temperatura"
#define MSG_NOZZLE1                      "Nozzle2"
#define MSG_NOZZLE2                      "Nozzle3"
#define MSG_BED                          "Piano"
#define MSG_FAN_SPEED                    "Vel. ventola"
#define MSG_FLOW                         "Flusso"
#define MSG_CONTROL                      "Controllo"
#define MSG_MIN                          "\002 min"
#define MSG_MAX                          "\002 max"
#define MSG_FACTOR                       "\002 effett."
#define MSG_AUTOTEMP                     "Auto temp."
#define MSG_ON                           "On"
#define MSG_OFF                          "Off"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Accel."
#define MSG_VXY_JERK                     "Vxy-jerk"
#define MSG_VZ_JERK                      "Vz-jerk"
#define MSG_VE_JERK                      "Ve-jerk"
#define MSG_VMAX                         "V.max"
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "V.min"
#define MSG_VTRAV_MIN                    "V.trav min"
#define MSG_AMAX                         "A.max "
#define MSG_A_RETRACT                    "Accel. ritraz."
#define MSG_XSTEPS                       "X passi/mm"
#define MSG_YSTEPS                       "Y passi/mm"
#define MSG_ZSTEPS                       "Z passi/mm"
#define MSG_ESTEPS                       "E passi/mm"
#define MSG_RECTRACT                     "Ritrai"
#define MSG_TEMPERATURE                  "Temperatura"
#define MSG_MOTION                       "Movimento"
#define MSG_CONTRAST                     "Contrasto LCD"
#define MSG_STORE_EPROM                  "Salva memoria"
#define MSG_LOAD_EPROM                   "Carica memoria"
#define MSG_RESTORE_FAILSAFE             "Riprist. fail-safe"
#define MSG_REFRESH                      "Refresh"
#define MSG_WATCH                        "Info display"
#define MSG_PREPARE                      "Prepara"
#define MSG_TUNE                         "Regola"
#define MSG_PAUSE_PRINT                  "Interrompi stampa"
#define MSG_PAUSED                       "Premi per riprendere"
#define MSG_PAUSING                      "In pausa..."
#define MSG_PRINTING                     "Stampa in corso..."
#define MSG_READY_UNLOAD                 "Premi e scarica filam."
#define MSG_UNLOAD_CLICK                 "Premi per continuare"
#define MSG_LOAD_CLICK                   "Carica nuovo filam."
#define MSG_RESUME_PRINT                 "Riprendi stampa"
#define MSG_STOP_PRINT                   "Arresta stampa"
#define MSG_CARD_MENU                    "Stampa da SD"
#define MSG_NO_CARD                      "Nessuna SD Card"
#define MSG_DWELL                        "Stand-by..."
#define MSG_USERWAIT                     "In attesa..."
#define MSG_RESUMING                     "Ripresa stampa in corso"
#define MSG_NO_MOVE                      "Nessun movimento"
#define MSG_KILLED                       "PROCESSO TERMINATO. "
#define MSG_STOPPED                      "PROCESSO ARRESTATO."
#define MSG_CONTROL_RETRACT              "Ritrai mm"
#define MSG_CONTROL_RETRACTF             "Ritrai F"
#define MSG_CONTROL_RETRACT_ZLIFT        "Alza mm"
#define MSG_CONTROL_RETRACT_RECOVER      "Riprist. ritraz. + mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "Riprist. ritraz. F"
#define MSG_AUTORETRACT                  "Auto-ritraz."
#define MSG_FILAMENTCHANGE               "Cambia filam."
#define MSG_INIT_SDCARD                  "Inizializ. SD Card"
#define MSG_CNG_SDCARD                   "Cambia SD Card"
#define MSG_ZPROBE_OUT                   "Verifica Z fuori piano"
#define MSG_POSITION_UNKNOWN             "Home X/Y prima di Z"
#define MSG_ZPROBE_ZOFFSET               "Z offset"
#define MSG_BABYSTEP_X                   "Babystep X"
#define MSG_BABYSTEP_Y                   "Babystep Y"
#define MSG_BABYSTEP_Z                   "Babystep Z"
#define MSG_ENDSTOP_ABORT                "Ferma endstop"
#define MSG_END_HOUR                     "ore"
#define MSG_END_MINUTE                   "minuti"
#define MSG_FILAMENT                     "Filamento"
#define MSG_LEVEL_PLATE                  "Livella il piano"
#define MSG_START_SCRIPT                 "Avvia script"
#define MSG_PREHEAT                      "Preriscalda"
#define MSG_JOG                          "Jog"
#define MSG_LOAD                         "Carica"
#define MSG_UNLOAD                       "Scarica"
#define MSG_ABORT                        "Ferma"
#define MSG_PRE_EXTRUD                   "Inserisci e premi"
#define MSG_EXTRUDING                    "Estrusione in corso..."
#define MSG_LENGTH                       "Lungh.:"
#define MSG_RETRACTING                   "Ritrazione..."
#define MSG_LP_COOL_1                    "Raffreddamento..."
#define MSG_LP_COOL_2                    "Temp.:"
#define MSG_LP_COOL_3                    "Premi per fermare"
#define MSG_LB_COOL_1                    "Raffreddamento..."
#define MSG_LB_COOL_2                    "Temp.:"
#define MSG_CF_HEAT_1                    "Riscaldamento..."
#define MSG_CF_HEAT_2                    "Temp.:"
#define MSG_EXIT                         "Premi per fermare..."
#define MSG_WIZARD_LEVELBED_0_1          "Livella. del piano: "
#define MSG_WIZARD_LEVELBED_0_2          "Premi per avviare"
#define MSG_WIZARD_LEVELBED_1_1          "Regola primo punto"
#define MSG_WIZARD_LEVELBED_1_2          "e premi il pulsante"
#define MSG_WIZARD_LEVELBED_2_1          "Regola secondo punto"
#define MSG_WIZARD_LEVELBED_2_2          "e premi il pulsante"
#define MSG_WIZARD_LEVELBED_3_1          "Regola terzo punto"
#define MSG_WIZARD_LEVELBED_3_2          "e premi il pulsante"
#define MSG_WIZARD_LEVELBED_4_1          "Regola quarto punto"
#define MSG_WIZARD_LEVELBED_4_2          "e premi il pulsante"
#define MSG_WIZARD_LEVELBED_5_1          "E' corretto?"
#define MSG_WIZARD_LEVELBED_6_1          "Piano livellato!"
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Premi il pulsan. per"
#define MSG_WIZARD_CHANGEFILAMENT_0_1    "avviare il processo"
#define MSG_WIZARD_CHANGEFILAMENT_0_2    "e estrarre il filam."
#define MSG_WIZARD_CHANGEFILAMENT_1_0    "Spingi il filamento"
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "rapidamente quando"
#define MSG_WIZARD_CHANGEFILAMENT_1_2    "si interr. l'estrus."
#define MSG_WIZARD_CHANGEFILAMENT_2_0    "Inserisci il nuovo"
#define MSG_WIZARD_CHANGEFILAMENT_2_1    "filamento e premi"
#define MSG_WIZARD_CHANGEFILAMENT_2_2    "il pulsante"
#define MSG_WIZARD_CHANGEFILAMENT_3_0    "Quando il filamento"
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "fuoriesce, premi il"
#define MSG_WIZARD_CHANGEFILAMENT_3_2    "pulsan. per riprend."
#define MSG_WIZARD_CHANGEFILAMENT_3_3    "la stampa"
#define MSG_SD_BAD_FILENAME              "Nome del file non valido!"
#define MSG_HEATING_PROCESS              "Riscaldamento..."
#define MSG_HEATING_DONE                 "Riscal. completato."
#define MSG_BED_HEATING_PROCESS          "Riscal. piano."
#define MSG_BED_HEATING_DONE             "Riscal.piano complet"
#define MSG_ENDSTOPS_TOUCH               "endstop raggiunto: "
#endif


#if LANGUAGE_CHOICE == 8
#define WELCOME_MSG MACHINE_NAME         " pronta"
#define MSG_SD_INSERTED                  "Cartao inserido"
#define MSG_SD_REMOVED                   "Cartao extraido"
#define MSG_MAIN                         "Menu principal"
#define MSG_BACK                         "Voltar"
#define MSG_AUTOSTART                    "Incio automatico"
#define MSG_DISABLE_STEPPERS             "Desligar motores"
#define MSG_AUTO_HOME                    "Ir a origem"
#define MSG_SET_ORIGIN                   "Selecionar origem"
#define MSG_PREHEAT_PLA                  "Preaquecer PLA"
#define MSG_PREHEAT_PLA_SETTINGS         "Configurar temp. PLA"
#define MSG_PREHEAT_ABS                  "Preaquecer ABS"
#define MSG_PREHEAT_ABS_SETTINGS         "Configurar temp. ABS"
#define MSG_COOLDOWN                     "Arrefecer"
#define MSG_SWITCH_PS_ON                 "Ligar energia"
#define MSG_SWITCH_PS_OFF                "Desligar energia"
#define MSG_EXTRUDE                      "Extrudir"
#define MSG_RETRACT                      "Retrair"
#define MSG_MOVE_AXIS                    "Mover eixos"
#define MSG_MOVE_X                       "Mover X"
#define MSG_MOVE_Y                       "Mover Y"
#define MSG_MOVE_Z                       "Mover Z"
#define MSG_MOVE_E                       "Extrusor"
#define MSG_MOVE_01MM                    "Mover 0,1 mm"
#define MSG_MOVE_1MM                     "Mover 1 mm"
#define MSG_MOVE_10MM                    "Mover 10 mm"
#define MSG_SPEED                        "Velocidade"
#define MSG_NOZZLE                       "Bocal"
#define MSG_NOZZLE1                      "Bocal2"
#define MSG_NOZZLE2                      "Bocal3"
#define MSG_BED                          "Base"
#define MSG_FAN_SPEED                    "Veloc ventoinha"
#define MSG_FLOW                         "Fluxo"
#define MSG_CONTROL                      "Controlo"
#define MSG_MIN                          " \002 Min"
#define MSG_MAX                          " \002 Max"
#define MSG_FACTOR                       "\002 Fator"
#define MSG_AUTOTEMP                     "Temp automatica"
#define MSG_ON                           "Ligado"
#define MSG_OFF                          "Desligado"
#define MSG_PID_P                        "PID-P"
#define MSG_PID_I                        "PID-I"
#define MSG_PID_D                        "PID-D"
#define MSG_PID_C                        "PID-C"
#define MSG_ACC                          "Acelerar"
#define MSG_VXY_JERK                     "Solavanco-Vxy"
#define MSG_VZ_JERK                      "Solavanco-Vz"
#define MSG_VE_JERK                      "Solavanco-Ve"
#define MSG_VMAX                         "Vmax "
#define MSG_X                            "x"
#define MSG_Y                            "y"
#define MSG_Z                            "z"
#define MSG_E                            "e"
#define MSG_VMIN                         "Vmin"
#define MSG_VTRAV_MIN                    "VTrav min"
#define MSG_AMAX                         "Amax "
#define MSG_A_RETRACT                    "Retrair-A"
#define MSG_XSTEPS                       "Xpassos/mm"
#define MSG_YSTEPS                       "Ypassos/mm"
#define MSG_ZSTEPS                       "Zpassos/mm"
#define MSG_ESTEPS                       "Epassos/mm"
#define MSG_RECTRACT                     "Retrair"
#define MSG_TEMPERATURE                  "Temperatura"
#define MSG_MOTION                       "Movimento"
#define MSG_CONTRAST                     "Contraste do LCD"
#define MSG_STORE_EPROM                  "Armazenar memoria"
#define MSG_LOAD_EPROM                   "Carregar memoria"
#define MSG_RESTORE_FAILSAFE             "Rest. seg. de falha"
#define MSG_REFRESH                      "Atualizar"
#define MSG_WATCH                        "Ecra de info"
#define MSG_PREPARE                      "Preparar"
#define MSG_TUNE                         "Afinar"
#define MSG_PAUSE_PRINT                  "Pausar impressao"
#define MSG_PAUSED                       "Premir para cont."
#define MSG_PAUSING                      "A pausar..."
#define MSG_PRINTING                     "A imprimir..."
#define MSG_READY_UNLOAD                 "Premir descarr fil."
#define MSG_UNLOAD_CLICK                 "Premir para cont"
#define MSG_LOAD_CLICK                   "Carregar filamento"
#define MSG_RESUME_PRINT                 "Retomar impressao"
#define MSG_STOP_PRINT                   "Parar impressao"
#define MSG_CARD_MENU                    "Imprimir do SD"
#define MSG_NO_CARD                      "Sem cartao SD"
#define MSG_DWELL                        "Repouso..."
#define MSG_USERWAIT                     "Aguardar ordem"
#define MSG_RESUMING                     "Retomar impressao"
#define MSG_NO_MOVE                      "Sem mover."
#define MSG_KILLED                       "CORTADO. "
#define MSG_STOPPED                      "PARADO. "
#define MSG_CONTROL_RETRACT              "Retrair mm"
#define MSG_CONTROL_RETRACTF             "Retrair F"
#define MSG_CONTROL_RETRACT_ZLIFT        "Elevar mm"
#define MSG_CONTROL_RETRACT_RECOVER      "Inv. Ret. +mm"
#define MSG_CONTROL_RETRACT_RECOVERF     "Inv. Ret. F"
#define MSG_AUTORETRACT                  "Retrair auto."
#define MSG_FILAMENTCHANGE               "Alterar filam."
#define MSG_INIT_SDCARD                  "Inic. cartao SD"
#define MSG_CNG_SDCARD                   "Alterar cartao SD"
#define MSG_ZPROBE_OUT                   "Sonda fora cam. Z"
#define MSG_POSITION_UNKNOWN             "Inic. X/Y antes Z"
#define MSG_ZPROBE_ZOFFSET               "Desvio Z"
#define MSG_BABYSTEP_X                   "Passo peq. X"
#define MSG_BABYSTEP_Y                   "Passo peq. Y"
#define MSG_BABYSTEP_Z                   "Passo peq. Z"
#define MSG_ENDSTOP_ABORT                "Abortar fim de curso"
#define MSG_END_HOUR                     "horas"
#define MSG_END_MINUTE                   "minutos"
#define MSG_FILAMENT                     "Filamento"
#define MSG_LEVEL_PLATE                  "Nivelar base"
#define MSG_START_SCRIPT                 "Iniciar sequencia"
#define MSG_PREHEAT                      "Preaquecer"
#define MSG_JOG                          "Mover"
#define MSG_LOAD                         "Carregar"
#define MSG_UNLOAD                       "Descarregar"
#define MSG_ABORT                        "Abortar"
#define MSG_PRE_EXTRUD                   "Inserir e premir"
#define MSG_EXTRUDING                    "A extrudir..."
#define MSG_LENGTH                       "Comprimento:"
#define MSG_RETRACTING                   "A retrair"
#define MSG_LP_COOL_1                    "A arrefec..."
#define MSG_LP_COOL_2                    "Temp.:"
#define MSG_LP_COOL_3                    "Prima para abort."
#define MSG_LB_COOL_1                    "A arrefec..."
#define MSG_LB_COOL_2                    "Temp.:"
#define MSG_CF_HEAT_1                    "A aquecer..."
#define MSG_CF_HEAT_2                    "Temp.:"
#define MSG_EXIT                         "Prima para abort..."
#define MSG_WIZARD_LEVELBED_0_1          "A nivelar placa... "
#define MSG_WIZARD_LEVELBED_0_2          "Prima para iniciar"
#define MSG_WIZARD_LEVELBED_1_1          "Ajustar prim. ponto"
#define MSG_WIZARD_LEVELBED_1_2          "e prima o botao"
#define MSG_WIZARD_LEVELBED_2_1          "Ajustar seg. ponto"
#define MSG_WIZARD_LEVELBED_2_2          "e prima o botao"
#define MSG_WIZARD_LEVELBED_3_1          "Ajustar terc. ponto"
#define MSG_WIZARD_LEVELBED_3_2          "e prima o botao"
#define MSG_WIZARD_LEVELBED_4_1          "Ajustar quar. ponto"
#define MSG_WIZARD_LEVELBED_4_2          "e prima o botao"
#define MSG_WIZARD_LEVELBED_5_1          "Esta ok? "
#define MSG_WIZARD_LEVELBED_6_1          " Placa nivelada! "
#define MSG_WIZARD_CHANGEFILAMENT_0_0    "Prima o bot. para"
#define MSG_WIZARD_CHANGEFILAMENT_0_1    " iniciar o proces. "
#define MSG_WIZARD_CHANGEFILAMENT_0_2    "e extrair o fil."
#define MSG_WIZARD_CHANGEFILAMENT_1_0    " Puxe o fil. "
#define MSG_WIZARD_CHANGEFILAMENT_1_1    "rapid. quando"
#define MSG_WIZARD_CHANGEFILAMENT_1_2    " parar de extrude. "
#define MSG_WIZARD_CHANGEFILAMENT_2_0    " Insira o novo "
#define MSG_WIZARD_CHANGEFILAMENT_2_1    " fil. e prima "
#define MSG_WIZARD_CHANGEFILAMENT_2_2    " o botao "
#define MSG_WIZARD_CHANGEFILAMENT_3_0    " Quando o fil. "
#define MSG_WIZARD_CHANGEFILAMENT_3_1    "extrude., prima o "
#define MSG_WIZARD_CHANGEFILAMENT_3_2    " botao para resum. "
#define MSG_WIZARD_CHANGEFILAMENT_3_3    "impressao"
#define MSG_SD_BAD_FILENAME              "Nome de fich. nulo!"
#define MSG_HEATING_PROCESS              "A aquecer..."
#define MSG_HEATING_DONE                 "Aquecimento concl."
#define MSG_BED_HEATING_PROCESS          "Base a aquecer."
#define MSG_BED_HEATING_DONE             "Base concluida."
#define MSG_ENDSTOPS_TOUCH               "fim de curso: "
#endif

#endif // ifndef LANGUAGE_H
